@@ -23,13 +23,11 @@ class TestPersistent < Minitest::Test
       [status, @headers, @body]
     end
 
-    @port = UniquePort.call
-
-    @server = Puma::Server.new @simple
-    @server.add_tcp_listener HOST, @port
-    @server.max_threads = 1
+    opts = {max_threads: 1}
+    @server = Puma::Server.new @simple, nil, opts
+    @port = (@server.add_tcp_listener HOST, 0).addr[1]
     @server.run
-
+    sleep 0.15 if Puma.jruby?
     @client = TCPSocket.new HOST, @port
   end
 
@@ -39,9 +37,9 @@ class TestPersistent < Minitest::Test
   end
 
   def lines(count, s=@client)
-    str = "".dup
+    str = +''
     Timeout.timeout(5) do
-      count.times { str << s.gets }
+      count.times { str << (s.gets || "") }
     end
     str
   end
@@ -95,6 +93,7 @@ class TestPersistent < Minitest::Test
 
   def test_chunked
     @body << "Chunked"
+    @body = @body.to_enum
 
     @client << @valid_request
 
@@ -104,6 +103,7 @@ class TestPersistent < Minitest::Test
   def test_chunked_with_empty_part
     @body << ""
     @body << "Chunked"
+    @body = @body.to_enum
 
     @client << @valid_request
 
@@ -112,6 +112,7 @@ class TestPersistent < Minitest::Test
 
   def test_no_chunked_in_http10
     @body << "Chunked"
+    @body = @body.to_enum
 
     @client << @http10_request
 
@@ -122,6 +123,7 @@ class TestPersistent < Minitest::Test
   def test_hex
     str = "This is longer and will be in hex"
     @body << str
+    @body = @body.to_enum
 
     @client << @valid_request
 
@@ -154,7 +156,7 @@ class TestPersistent < Minitest::Test
   end
 
   def test_persistent_timeout
-    @server.persistent_timeout = 1
+    @server.instance_variable_set(:@persistent_timeout, 1)
     @client << @valid_request
     sz = @body[0].size.to_s
 
@@ -191,7 +193,7 @@ class TestPersistent < Minitest::Test
 
 
   def test_two_requests_in_one_chunk
-    @server.persistent_timeout = 3
+    @server.instance_variable_set(:@persistent_timeout, 3)
 
     req = @valid_request.to_s
     req += "GET /second HTTP/1.1\r\nHost: test.com\r\nContent-Type: text/plain\r\n\r\n"
@@ -208,7 +210,7 @@ class TestPersistent < Minitest::Test
   end
 
   def test_second_request_not_in_first_req_body
-    @server.persistent_timeout = 3
+    @server.instance_variable_set(:@persistent_timeout, 3)
 
     req = @valid_request.to_s
     req += "GET /second HTTP/1.1\r\nHost: test.com\r\nContent-Type: text/plain\r\n\r\n"
@@ -235,10 +237,7 @@ class TestPersistent < Minitest::Test
     c2 = TCPSocket.new HOST, @port
     c2 << @valid_request
 
-    out = IO.select([c2], nil, nil, 1)
-
-    assert out, "select returned nil"
-    assert_equal c2, out.first.first
+    assert c2.wait_readable(1), "2nd request starved"
 
     assert_equal "HTTP/1.1 200 OK\r\nX-Header: Works\r\nContent-Length: #{sz}\r\n\r\n", lines(4, c2)
     assert_equal "Hello", c2.read(5)
